---
title: "DORA"
description: "Terraform compliance scanning for DORA — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Team" variant="caution" />
<Badge text="Financial" variant="tip" />

**Issuing body:** [European Parliament](https://www.europarl.europa.eu)
**Jurisdiction:** Regional — Europe
**Countries:** All 27 EU member states


## Assessment

Assess your infrastructure against DORA for free at any tier:

```bash
complyform assess --frameworks=dora
```

## Remediation

Requires Team tier or higher ($1,999/yr) for remediation.

```bash
complyform remediate --frameworks=dora
```

## Related Frameworks

- [GDPR](/frameworks/gdpr)
- [NIS2 Directive](/frameworks/nis2)
- [BSI C5](/frameworks/bsi_c5)
- [ENS](/frameworks/ens)
